@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -25,17 +23,20 @@
  *
  */
 
-let MimeHandler = imports.ui.mimeHandler;
-let Gst = imports.gi.Gst;
-let Gio = imports.gi.Gio;
+const Gio = imports.gi.Gio;
+const Gst = imports.gi.Gst;
+const Gtk = imports.gi.Gtk;
+const GtkClutter = imports.gi.GtkClutter;
+const Sushi = imports.gi.Sushi;
 
-let Gettext = imports.gettext.domain('sushi');
-let _ = Gettext.gettext;
+const Gettext = imports.gettext.domain('sushi');
+const _ = Gettext.gettext;
+const Lang = imports.lang;
 
-let Constants = imports.util.constants;
-let TotemMimeTypes = imports.util.totemMimeTypes;
-
-let Utils = imports.ui.utils;
+const Constants = imports.util.constants;
+const MimeHandler = imports.ui.mimeHandler;
+const TotemMimeTypes = imports.util.totemMimeTypes;
+const Utils = imports.ui.utils;
 
 function AudioRenderer(args) {
     this._init(args);
@@ -63,8 +64,8 @@ AudioRenderer.prototype = {
         let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
                                  spacing: 1,
                                  margin_top: 48,
-                                 margin_left: 12,
-                                 margin_right: 12 });
+                                 margin_start: 12,
+                                 margin_end: 12 });
         this._box.pack_start(vbox, false, false, 0);
 
         this._titleLabel = new Gtk.Label();
@@ -236,9 +237,7 @@ AudioRenderer.prototype = {
             this._toolbarPlay.set_icon_name('media-playback-pause-symbolic');
             break;
         default:
-            let iconName =
-            (this._toolbarPlay.get_direction() == Gtk.TextDirection.RTL) ?
-                'media-playback-start-rtl-symbolic' : 'media-playback-start-symbolic';
+            let iconName = 'media-playback-start-symbolic';
             this._toolbarPlay.set_icon_name(iconName);
         }
     },
@@ -270,8 +269,8 @@ AudioRenderer.prototype = {
         this._toolbarPlay.show();
         this._mainToolbar.insert(this._toolbarPlay, 0);
 
-        this._currentLabel = new Gtk.Label({ margin_left: 6,
-                                             margin_right: 3 });
+        this._currentLabel = new Gtk.Label({ margin_start: 6,
+                                             margin_end: 3 });
         let item = new Gtk.ToolItem();
         item.add(this._currentLabel);
         item.show_all();
@@ -300,7 +299,7 @@ AudioRenderer.prototype = {
         item.show_all();
         this._mainToolbar.insert(item, 2);
 
-        this._durationLabel = new Gtk.Label({ margin_left: 3 });
+        this._durationLabel = new Gtk.Label({ margin_start: 3 });
         item = new Gtk.ToolItem();
         item.add(this._durationLabel);
         item.show_all();
